.. include:: ../README.rst

.. toctree::
    :hidden:
    :titlesonly:

    self

.. toctree::
    :maxdepth: 2

    user_guide
    contribute
    changelog

    Code Coverage <https://examples.pages.km3net.de/dom_autopsy/coverage>
    Source (Git) <https://git.km3net.de/jseneca/dom_autopsy>

* :ref:`genindex`
